@@ -3,7 +3,7 @@ package Apache::Session::Serialize::MongoDB;
 use 5.010;
 use strict;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 sub serialize {
     my $session = shift;
@@ -18,7 +18,7 @@ __END__
 
 =head1 NAME
 
-Apache::Session::Serialize::MongoDB - Do nothing since MongoDB can store Perl
+Apache::Session::Serialize::MongoDB - Does nothing since MongoDB can store Perl
 objects;
 
 =head1 SYNOPSIS
@@ -40,11 +40,11 @@ L<Apache::Session::Store::MongoDB>
 
 =head1 AUTHOR
 
-Xavier Guimard, E<lt>x.guimard@free.fr<gt>
+Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015 by Xavier Guimard, E<lt>x.guimard@free.fr<gt>
+Copyright (C) 2015 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
